package usingjsp;

import java.io.*;
import java.util.*;
import java.sql.*;
import javax.servlet.*;

public class ControllerServlet extends GenericServlet
{
    protected Connection conn;

    public void init()
    {
        try
        {
// Make sure the JdbcOdbcDriver class is loaded
            Class.forName("sun.jdbc.odbc.JdbcOdbcDriver");

// Try to connect to a database via ODBC
            conn = DriverManager.getConnection(
                "jdbc:odbc:usingjsp");
        }
        catch (Exception exc)
        {
// If there's an error, use the servlet logging API
            getServletContext().log(
                "Error making JDBC connection: ", exc);
        }
    }

    public void destroy()
    {
        try
        {
// Only try to close the connection if it's non-null
            if (conn != null)
            {
                conn.close();
            }
        }
        catch (SQLException exc)
        {
// If there's an error, use the servlet logging API
            getServletContext().log(
                "Error closing JDBC connection: ", exc);
        }
    }

// This servlet isn't doing connection pooling, so just synchronize for
// thread safety.
// For production systems, don't do this, use a connection pool!

    public synchronized void service(ServletRequest request,
        ServletResponse response)
        throws java.io.IOException, ServletException
    {
        Statement stmt = null;

// Parse the minimum and maximum ages and go to an error page if they
// are invalid
        String minimumAgeStr = request.getParameter("minAge");
        int minimumAge = 0;

        try
        {
            minimumAge = Integer.parseInt(minimumAgeStr);
        }
        catch (Exception exc)
        {
            gotoPage("/jspbook/Chap07/BadAge.jsp?"+
                "reason=Invalid+minimum+age",
                request, response);
        }

        String maximumAgeStr = request.getParameter("maxAge");
        int maximumAge = 0;

        try
        {
            maximumAge = Integer.parseInt(maximumAgeStr);
        }
        catch (Exception exc)
        {
            gotoPage("/jspbook/Chap07/BadAge.jsp?"+
                "reason=Invalid+maximum+age",
                request, response);
        }

        try
        {
            stmt = conn.createStatement();

// Get all the people matching the criteria
            ResultSet results = stmt.executeQuery(
                "select * from person where age between "+
                    minimumAge+" and "+ maximumAge);

            Vector v = new Vector();

            while (results.next())
            {
// The person class can construct itself from a database row
                v.addElement(new Person(results));
            }

// Store the vector of person objects so the JSP can access it
            request.setAttribute("people", v);

            gotoPage("/jspbook/Chap07/ShowPeople.jsp",
                request, response);
        }
        catch (SQLException exc)
        {
            request.setAttribute("exception", exc.toString());
            gotoPage("/jspbook/Chap07/DatabaseError.jsp",
                request, response);
        }
        finally
        {
            try {
                stmt.close();
            } catch (Exception ignore) {}
        }
    }

// Since the servlet needs to forward to many pages, this method
// comes in handy as a one-liner for forwarding. It should really
// check to make sure it could get the dispatcher and do something
// predictable if it can't.

    public void gotoPage(String pageName,
        ServletRequest request, ServletResponse response)
        throws IOException, ServletException
    {
        RequestDispatcher d = getServletContext().
            getRequestDispatcher(pageName);
        
        d.forward(request, response);
    }
}
