package usingjsp;

import java.io.*;
import java.util.*;

/** Manages the meet file using the file locking mechanism. */
public class MeetManager
{
    public static void updateMeet(Meet meet)
        throws IOException
    {
        FileLock lock = new FileLock("meets");

        if (lock.lock())
        {
            BufferedReader reader = new BufferedReader(
                lock.getReader());

            PrintWriter writer = new PrintWriter(
                lock.getRewriteWriter());

            String line;

// Read each line in the file
            while ((line = reader.readLine()) != null)
            {
// Get the Meet object stored in the string
                Meet currMeet = new Meet(line);

// If this is the meet that is being updated, write out the
// new version of the meet instead of the old one
                if (currMeet.meetName.equalsIgnoreCase(meet.meetName))
                {
                    writer.println(meet.toDataString());
                }
                else
                {
// Otherwise, just copy the line
                    writer.println(line);
                }
            }

            writer.close();
            reader.close();
            lock.unlock();
        }
        else
        {
            throw new IOException("Unable to lock Meet file");
        }
    }

    public static void deleteMeet(String meetName)
        throws IOException
    {
        FileLock lock = new FileLock("meets");

        if (lock.lock())
        {
            BufferedReader reader = new BufferedReader(
                lock.getReader());

            PrintWriter writer = new PrintWriter(
                lock.getRewriteWriter());

            String line;

// Read each line in the file
            while ((line = reader.readLine()) != null)
            {
// Get the Meet object stored in the string
                Meet currMeet = new Meet(line);

// If this is the meet that is being deleted, just skip the line
                if (currMeet.meetName.equalsIgnoreCase(meetName))
                {
                    continue;
                }
                else
                {
// Otherwise, just copy the line
                    writer.println(line);
                }
            }

            writer.close();
            reader.close();
            lock.unlock();
        }
        else
        {
            throw new IOException("Unable to lock Meet file");
        }
    }

    public static void addMeet(Meet newMeet)
        throws IOException
    {
        FileLock lock = new FileLock("meets");

        if (lock.lock())
        {
// Instead of copying, you can just open the file for append to
// add a new meet
            PrintWriter writer = new PrintWriter(
                lock.getOutputStream(true));    // open for append
            
            writer.println(newMeet.toDataString());

            writer.close();
            lock.unlock();
        }
        else
        {
            throw new IOException("Unable to lock Meet file");
        }
    }

/** Returns a vector of all the meets in the file */
    public static Vector getAllMeets()
        throws IOException
    {
        Vector v = new Vector();

        FileLock lock = new FileLock("meets");

        if (lock.lock())
        {
            BufferedReader reader = new BufferedReader(
                lock.getReader());

            String line;

// Read each line, create a meet from the line, 
// then add the meet to the vector
            while ((line = reader.readLine()) != null)
            {
                Meet currMeet = new Meet(line);

                v.addElement(currMeet);
            }

            reader.close();
            lock.unlock();

            return v;
        }
        else
        {
            throw new IOException("Unable to lock Meet file");
        }
    }
}
