package usingjsp;

import java.io.*;
import java.util.*;

/** Manages the meet file using the file locking mechanism. */
public class MeetManager3
{
    public static void updateMeet(Meet3 meet)
        throws IOException
    {
        FileLock lock = new FileLock("meets.rnd");

        if (lock.lock())
        {
            
// Open the locked file as a random-access file
            RandomAccessFile file = lock.getRandomAccessFile();

// Go to the position in the file where this meet is located
            file.seek(meet.meetIndex * Meet3.getMaxSize());

// Convert this meet into an array of bytes
            byte[] meetBytes = getMeetBytes(meet);

// Write the meet into the file
            file.write(meetBytes);

            file.close();
            lock.unlock();
        }
        else
        {
            throw new IOException("Unable to lock Meet file");
        }
    }

    public static void deleteMeet(int meetIndex)
        throws IOException
    {
        FileLock lock = new FileLock("meets.rnd");

        if (lock.lock())
        {
// Open the locked file as a random-access file
            RandomAccessFile file = lock.getRandomAccessFile();

// Go to the position in the file where this meet is located
            file.seek(meetIndex * Meet3.getMaxSize());

// Set the value of the object at this location to null (and convert the
// null into an array of bytes)
            byte[] meetBytes = getMeetBytes(null);

// Write the null object back to the file
            file.write(meetBytes);

            file.close();
            lock.unlock();
        }
    }

    public static void addMeet(Meet3 newMeet)
        throws IOException
    {
        FileLock lock = new FileLock("meets.rnd");

        if (lock.lock())
        {
// Open the locked file as a random-access file
            RandomAccessFile file = lock.getRandomAccessFile();

// Calculate the number of meets. The end of the file may be less than
// Meet3.getMaxSize bytes long, so add padding to the file length to make
// sure the calculation comes out right
            int numMeets = (int) ((file.length() + Meet3.getMaxSize() - 1)
                 / Meet3.getMaxSize());

            byte[] buffer = new byte[Meet3.getMaxSize()];

            int newIndex = numMeets;

// Search through the file for any blank spots
            for (int i=0; i < numMeets; i++)
            {
                file.read(buffer);
                Meet3 currMeet = getMeetFromBytes(buffer);

// If there is a null meet, the new meet can be put there
                if (currMeet == null)
                {
                    newIndex = i;
                    break;
                }
            }

// Store the new meet wherever there was a blank spot, or at the
// end of the file.
            newMeet.meetIndex = newIndex;
            file.seek(newMeet.meetIndex * Meet3.getMaxSize());
            byte[] meetBytes = getMeetBytes(newMeet);
            file.write(meetBytes);

            file.close();
            lock.unlock();
        }
        else
        {
            throw new IOException("Unable to lock Meet file");
        }
    }

/** Returns a vector of all the meets in the file */
    public static Vector getAllMeets()
        throws IOException
    {
        FileLock lock = new FileLock("meets.rnd");

        if (lock.lock())
        {
// Open the locked file as a random-access file
            RandomAccessFile file = lock.getRandomAccessFile();

// Calculate the number of meets. The end of the file may be less than
// Meet3.getMaxSize bytes long, so add padding to the file length to make
// sure the calculation comes out right
            int numMeets = (int) ((file.length() + Meet3.getMaxSize() - 1)
                 / Meet3.getMaxSize());

            byte[] buffer = new byte[Meet3.getMaxSize()];

            Vector v = new Vector();

// Loop through all the meets
            for (int i=0; i < numMeets; i++)
            {
// Read in the byte buffer representing the serialized meet
                file.read(buffer);

// Convert the bytes into an object
                Meet3 currMeet = getMeetFromBytes(buffer);

// If the object isn't null, add it to the current list
                if (currMeet != null)
                {
                    v.addElement(currMeet);
                }
            }

            file.close();
            lock.unlock();

            return v;
        }
        else
        {
            throw new IOException("Unable to lock Meet file");
        }
    }

    public static Meet3 getMeet(int meetIndex)
        throws IOException
    {
        FileLock lock = new FileLock("meets.rnd");

        if (lock.lock())
        {
            
// Open the locked file as a random-access file
            RandomAccessFile file = lock.getRandomAccessFile();

// Go to the position in the file where this meet is located
            file.seek(meetIndex * Meet3.getMaxSize());
            byte[] buffer = new byte[Meet3.getMaxSize()];

// Read in the byte buffer representing the serialized meet
            file.read(buffer);

// Convert the bytes into an object
            Meet3 meet = getMeetFromBytes(buffer);

            file.close();
            lock.unlock();

            return meet;
        }
        else
        {
            throw new IOException("Unable to lock Meet file");
        }
    }

/** Converts a Meet3 object into an array of bytes */

    public static byte[] getMeetBytes(Meet3 meet)
        throws IOException
    {
// Create a ByteArrayOutputStream that will convert data written to
// a stream into an array of bytes
        ByteArrayOutputStream out = new ByteArrayOutputStream(
            Meet3.getMaxSize());

// Wrap an ObjectOutputStream around the byte array stream
        ObjectOutputStream obOut = new ObjectOutputStream(out);

// Write the object out to the stream
        obOut.writeObject(meet);

// Convert the stream into an array of bytes
        byte[] bytes = out.toByteArray();

// Free up any resources used by the stream
        out.close();
        return bytes;
    }

/** Converts an array of bytes into a Meet3 object */
    public static Meet3 getMeetFromBytes(byte[] bytes)
        throws IOException
    {
// Treat the array of bytes as a stream
        ByteArrayInputStream in = new ByteArrayInputStream(bytes);

// Wrap an ObjectInputStream around the byte stream 
        ObjectInputStream obIn = new ObjectInputStream(in);

        Meet3 meet = null;

        try
        {
// Read the object from the stream
            meet = (Meet3) obIn.readObject();
        }
        catch (ClassNotFoundException exc)
        {
            throw new IOException("Invalid class stored in file");
        }

// Free up any resources used by the stream
        in.close();
        return meet;
    }
}
