package usingjsp.problemreport;

import javax.servlet.*;
import javax.servlet.http.*;
import usingjsp.*;
import java.sql.*;
import java.util.*;

/** Validates a user login and then calls the main Problem Reporting page */
public class LoginServlet2 extends HttpServlet
{
    public void service(HttpServletRequest request,
        HttpServletResponse response)
        throws java.io.IOException, ServletException
    {
// Get the user name and password from the login form
        String username = request.getParameter("username");
        String password = request.getParameter("password");

        if (username == null)
        {
            request.setAttribute("rejectReason",
                "No username specified");

            rejectLogin(request, response);

            return;
        }

        if (password == null)
        {
            request.setAttribute("rejectReason",
                "No password specified");

            rejectLogin(request, response);

            return;
        }

// Get the "application" context
        ServletContext context = getServletContext();

// See if the connection pool has already been created
        IConnectionPool pool = (IConnectionPool) context.getAttribute(
            "connectionPool");
    
// If not, the pool must be created
        if (pool == null)
        {
// Synchronize on the application object and check one more time
// for the pool just in case another thread is in the process
// of creating the pool

            synchronized(context)
            {
                pool = (IConnectionPool) context.getAttribute(
                    "connectionPool");
                if (pool == null)
                {
// Make sure the database driver is available
                    try {
                        Class.forName("org.gjt.mm.mysql.Driver").
                            newInstance();
                    } catch (Exception exc) {
                        getServletContext().log(
                            "Error loading JDBC driver", exc);
                    }
        
// Create the connection pool and store it in the application object
                    try
                    {
                        pool = new ConnectionPool(
                            "jdbc:mysql://localhost/usingjsp",
                            "", "", 10);
                        context.setAttribute("connectionPool", pool);
                    }
                    catch (SQLException exc)
                    {
                        context.log("Error creating connection pool", exc);
                    }
                }
            }
        }

        Connection conn = null;

        try
        {
            conn = pool.getConnection();

// Create a dummy developer object for performing a query
            Developer devQuery = new Developer();

// Find the developer object that matches the user name entered on the form
            Vector v = devQuery.getAll(conn, "username='"+
                username.toLowerCase()+"'");

// If the user name doesn't exist, show an error
            if (v.size() != 1)
            {
                request.setAttribute("rejectReason",
                    "Invalid username");

                rejectLogin(request, response);

                return;
            }

            Developer d = (Developer) v.elementAt(0);

// Make sure the passwords match
            if (!d.password.equals(password))
            {
                request.setAttribute("rejectReason",
                    "Invalid password");

                rejectLogin(request, response);

                return;
            }

            HttpSession session = request.getSession();

            session.setAttribute("username", username);
            session.setAttribute("developer", d.getDeveloper());

// Send the user on to the main screen
            RequestDispatcher dispatch =
                context.getRequestDispatcher(
                    "/jspbook/Chap19/ProblemReporting.jsp");
            
            dispatch.forward(request, response);
        }
        catch (SQLException exc)
        {
            getServletContext().log(
                "A database error occurred while validating a user",
                exc);

            request.setAttribute("rejectReason",
                "A database error has occurred");

            rejectLogin(request, response);

            return;
        }
        finally
        {
            if (conn != null)
            {
                try
                {
                    pool.releaseConnection(conn);
                }
                catch (Exception ignore)
                {
                }
            }
        }
    }

/** Displays an error if the login fails for any reason */
    public void rejectLogin(HttpServletRequest request,
        HttpServletResponse response)
        throws java.io.IOException, ServletException
    {
        RequestDispatcher dispatch =
            getServletContext().getRequestDispatcher(
                "/jspbook/Chap19/RejectLogin.jsp");
        
        dispatch.forward(request, response);
    }
}
