package usingjsp;

import java.sql.*;
import java.util.*;

/** A simple connection pool that allocates new connections where
 *  there are no more connections.
 */
public class SimpleConnectionPool implements IConnectionPool
{
    protected Stack pool;
    protected String connectionURL;
    protected String userName;
    protected String password;

/** Creates a new connection pool that creates connections using
 *  the specified URL, user name and password */
    public SimpleConnectionPool(String aConnectionURL,
        String aUserName, String aPassword)
    {
        connectionURL = aConnectionURL;
        userName = aUserName;
        password = aPassword;
        pool = new Stack();
    }

/** Gets a connection from the pool or creates one if the pool is empty */
    public synchronized Connection getConnection()
        throws SQLException
    {
// If the pool isn't empty, grab a connection from it
        if (!pool.empty())
        {
            return (Connection) pool.pop();
        }
        else
        {
// Otherwise, create a new connection
            return DriverManager.getConnection(connectionURL,
                userName, password);
        }
    }

/** Returns a connection to the pool */
    public synchronized void releaseConnection(Connection conn)
        throws SQLException
    {
        pool.push(conn);
    }
}
