package usingjsp.rmi;

import java.io.*;
import java.rmi.*;
import java.rmi.server.UnicastRemoteObject;

/** An implementation of the Message-Of-The-Day remote interfcae. */

public class MOTDImpl extends UnicastRemoteObject
    implements MOTD
{
/** The name of the file containing the message */
    protected String motdFileName;

/** Creates a new instance of the MOTD server assigned to a
 *  specific filename.
 */
    public MOTDImpl(String aMotdFileName)
        throws RemoteException
    {
        motdFileName = aMotdFileName;
    }

/** Returns the Message-Of-The-Day */
    public String getMOTD()
    {
        try
        {
// Open the message file
            BufferedReader reader = new BufferedReader(
                new FileReader(motdFileName));

// Create a buffer to hold the resulting message
            StringBuffer buffer = new StringBuffer();

            String line;

// Read all the lines in the file
            while ((line = reader.readLine()) != null)
            {
// Put each line into the buffer separated by newlines
                buffer.append(line);
                buffer.append("\n");
            }

            reader.close();

// Return the message
            return buffer.toString();
        }
        catch (IOException exc)
        {
// If there's an error, just return an empty message
            return "";
        }
    }

/** Activates the MOTD service */
    public static void main(String[] args)
    {
        String motdFile = System.getProperty("file", "motd.txt");
        String motdService = System.getProperty("service",
            "MessageOfTheDay");

// Must assign an RMI security manager
        if (System.getSecurityManager() == null)
        {
            System.setSecurityManager(new RMISecurityManager());
        }

        try
        {
// Create an instance of the MOTD service
            MOTDImpl impl = new MOTDImpl(motdFile);

// Register the service with the RMI registry
            Naming.rebind("//localhost/"+motdService, impl);

        }
        catch (Exception exc)
        {
            exc.printStackTrace();
        }
    }
}
