package usingjsp.service;

import java.rmi.*;
import java.rmi.server.UnicastRemoteObject;
import java.sql.*;
import usingjsp.IConnectionPool;

/** Provides a remote interface for manipulating a ServiceRequest object */

public class RemoteServiceRequestImpl extends UnicastRemoteObject
    implements RemoteServiceRequest
{
/** The real service request this object provides access to */
    protected ServiceRequest request;

/** A pool of database connections */
    protected IConnectionPool pool;

/** Creates a new, empty service request */
    public RemoteServiceRequestImpl(IConnectionPool aPool)
        throws RemoteException
    {
        pool = aPool;
        request = new ServiceRequest();
    }

/** Creates a wrapper around an existing service request */
    public RemoteServiceRequestImpl(ServiceRequest aRequest,
        IConnectionPool aPool)
        throws RemoteException
    {
        request = aRequest;
        pool = aPool;
    }

// The following get/set methods just invoke their corresponding
// get/set methods in the real ServiceRequest object

    public int getRequestId() { return request.getRequestId(); };
    public void setRequestId(int id) { request.setRequestId(id); }

    public String getOriginator() { return request.getOriginator(); }
    public void setOriginator(String o) { request.setOriginator(o); }

    public String getTitle() { return request.getTitle(); }
    public void setTitle(String t) { request.setTitle(t); }

    public String getDetails() { return request.getDetails(); }
    public void setDetails(String d) { request.setDetails(d); }

/** Inserts or updates a ServiceRequest object depending on whether
 *  the requestId field has been initialized or not
 */
    public void save()
        throws RemoteException
    {
        Connection conn = null;

        try
        {
            conn = pool.getConnection();

            if (request.getRequestId() <= 0)
            {
                request.insert(conn);
            }
            else
            {
                request.update(conn);
            }
        }
        catch (SQLException exc)
        {
            throw new RemoteException(
                "Got exception while saving object: "+exc.toString());
        }
        finally
        {
            if (conn != null)
            {
                try
                {
                    pool.releaseConnection(conn);
                } catch (Exception ignore) {
                }
            }
        }
    }

/** Deletes the service request from the database */
    public void delete()
        throws RemoteException
    {
        Connection conn = null;

        try
        {
            conn = pool.getConnection();

            request.delete(conn);
        }
        catch (SQLException exc)
        {
            throw new RemoteException(
                "Got exception while deleting object: "+exc.toString());
        }
        finally
        {
            if (conn != null)
            {
                try
                {
                    pool.releaseConnection(conn);
                } catch (Exception ignore) {
                }
            }
        }
    }
}
