package usingjsp.service;

import usingjsp.DatabaseObject;
import java.util.*;
import java.sql.*;

/** Provides data access to the service_request database table */

public class ServiceRequest extends DatabaseObject
    implements java.io.Serializable
{
    public int requestId;
    public String originator;
    public String title;
    public String details;

    public ServiceRequest()
    {
    }

/** Populates the data items from a database row */
    public ServiceRequest(ResultSet results)
        throws java.sql.SQLException
    {
        requestId = results.getInt("request_id");
        originator = results.getString("originator");
        title = results.getString("title");
        details = results.getString("details");
    }

    public int getRequestId() { return requestId; }
    public void setRequestId(int aRequestId) { requestId = aRequestId; }

    public String getOriginator() { return originator; }
    public void setOriginator(String anOriginator)
        { originator = anOriginator; }
    
    public String getTitle() { return title; }
    public void setTitle(String aTitle) { title = aTitle; }

    public String getDetails() { return details; }
    public void setDetails(String theDetails) { details = theDetails; }

/** Returns a list of fields to be used in a select statement */
    public String getFieldList()
    {
        return "request_id,originator,title,details";
    }

/** Returns the name of the table this class is mapped to */
    public String getTableName() { return "service_request"; }

/** Creates a new instance of this object populated with
 *  data from a database table.
 */
    public DatabaseObject createInstance(ResultSet results)
        throws SQLException
    {
        return new ServiceRequest(results);
    }

/** Inserts this object in the database and then updates the request
 *  id with the value automatically generated by the database.
 */
    public int insert(Connection conn)
        throws SQLException
    {
        int numRows = super.insert(conn);

        requestId = getSequenceNumber(conn);

        return numRows;
    }

/** Returns the SQL statement used to insert this object into the database */
    public String getInsertStatement()
    {
        return "insert into service_request (request_id, originator, "+
            "title, details) values (?,?,?,?)";
    }

/** Stores this object's data into the insert statement */
    public void prepareInsertStatement(PreparedStatement s)
        throws SQLException
    {
        s.setInt(1, 0);
        s.setString(2, originator);
        s.setString(3, title);
        s.setString(4, details);
    }

/** Returns the SQL statement used to update this object in the database */
    public String getUpdateStatement()
    {
        return "update service_request set originator=?, "+
            "title=?, details=? where request_id=?";
    }

/** Stores this object's data into the update statement */
    public void prepareUpdateStatement(PreparedStatement s)
        throws SQLException
    {
        s.setString(1, originator);
        s.setString(2, title);
        s.setString(3, details);
        s.setInt(4, requestId);
    }

/** Returns the SQL statement used to delete this object from the database */
    public String getDeleteStatement()
    {
        return "delete from service_request where request_id=?";
    }

/** Stores this object's primary key into the delete statement */
    public void prepareDeleteStatement(PreparedStatement s)
        throws SQLException
    {
        s.setInt(1, requestId);
    }
}
