package usingjsp;

import java.lang.reflect.*;
import org.omg.CORBA.portable.*;

public class NullToBlank
{
// Keep a copy of the string class object handy
// String.class is shorthand for Class.forName("java.lang.String"), it's
// better to keep a copy of it statically than to regenerate it with
// every call.

    public static Class stringClass = String.class;

/** Examines an object changing any null strings to blanks. If the object
 *  contains any nested CORBA structures, will examine those too.
 */
    public static void nullToBlank(Object ob)
    {
// If the object is an array, loop through the members
        if (ob instanceof Object[])
        {
            Object[] obArray = (Object[]) ob;
            for (int i=0; i < obArray.length; i++)
            {
// Convert nulls to an empty string in each element
                nullToBlank(obArray[i]);
            }
            return;
        }

// Get the list of fields in this object
        Field[] obFields = ob.getClass().getFields();

        for (int i=0; i < obFields.length; i++)
        {
            try
            {
// Get the object's value
                Object obValue = obFields[i].get(ob);

// See if the object is null
                if (obValue != null)
                {
// If it is an array or a CORBA object, loop through the object's fields
                    if ((obValue instanceof IDLEntity) ||
                        (obValue instanceof Object[]))
                    {
                        nullToBlank(obValue);
                    }
                    continue;
                }

// Get the object's class
                Class obClass = obFields[i].getType();

// See if this object is supposed to be a string. You can't use
// instanceof in this case because the value is null so you don't
// know what its real class is supposed to be
                if (obClass.equals(stringClass))
                {
                    obFields[i].set(ob, "");
                }
            }
            catch (IllegalAccessException ignore) {}
        }
    }
}

