package usingjsp.cart;

import usingjsp.cart.corba.*;
import org.omg.CORBA.*;
import java.util.*;

public class ShoppingCartImpl extends _IShoppingCartImplBase
{
    protected ShoppingCart cart;

    public ShoppingCartImpl()
    {
        cart = new ShoppingCart();
    }

/** Adds an item to the shopping cart */
    public void addItem(ItemInfo itemInfo)
    {
        Item item = new Item(itemInfo.productCode,
            itemInfo.description, itemInfo.price,
            itemInfo.quantity);

        cart.addItem(item);
    }

/** Removes an item from the shopping cart */
    public void removeItem(int itemIndex)
    {
        cart.removeItem(itemIndex);
    }

/** Returns an array of the items in the shopping cart */
    public ItemInfo[] getItems()
    {
// Get the items from the cart
        Vector items = cart.getItems();

// Create an array for returning the values
        ItemInfo[] itemInfos = new ItemInfo[items.size()];

        for (int i=0; i < itemInfos.length; i++)
        {
// Get the item from the vector
            Item item = (Item) items.elementAt(i);
        
// Create a CORBA version of the item
            itemInfos[i] = new ItemInfo(item.productCode,
                item.description, item.price,
                item.quantity);
        }

        return itemInfos;
    }

/** Asks the shopping cart to complete the order */
    public String completeOrder(ShippingInfo shippingInfo,
        BillingInfo billingInfo)
        throws usingjsp.cart.corba.ShoppingCartException
    {
// Copy the CORBA version of the billing information into a Billing object
        Billing billing = new Billing();

        billing.nameOnCard = billingInfo.nameOnCard;
        billing.creditCardType = billingInfo.creditCardType;
        billing.creditCardNumber = billingInfo.creditCardNumber;
        billing.creditCardExpiration = billingInfo.creditCardExpiration;

// Copy the CORBA version of the shipping information into a Shipping object
        Shipping shipping = new Shipping();
        shipping.name = shippingInfo.name;
        shipping.address1 = shippingInfo.address1;
        shipping.address2 = shippingInfo.address2;
        shipping.city = shippingInfo.city;
        shipping.state = shippingInfo.state;
        shipping.country = shippingInfo.country;
        shipping.postalCode = shippingInfo.postalCode;
        shipping.email = shippingInfo.email;

        try
        {
            return cart.completeOrder(shipping, billing);
        }
        catch (usingjsp.cart.ShoppingCartException exc)
        {
            throw new usingjsp.cart.corba.ShoppingCartException(
                exc.getMessage());
        }
    }
}
