package usingjsp.ejb;

import javax.ejb.*;
import java.sql.*;
import javax.sql.*;
import javax.naming.*;
import java.util.*;

/** A data object representing an Address for an address book database
 */
public class AddressEJBBMP
    implements EntityBean, java.io.Serializable
{
    public String firstName;
    public String middleName;
    public String lastName;
    public String homePhoneNumber;
    public String workPhoneNumber;
    public String mobilePhoneNumber;
    public String address1;
    public String address2;
    public String city;
    public String state;
    public String zip;
    public String email;

    private EntityContext context;
    private Connection conn;
    private static String dbName = "java:comp/env/jdbc/AddressDB";

    public AddressEJBBMP()
    {
    }

    public AddressKey ejbCreate(String aFirstName, String aMiddleName,
        String aLastName)
        throws CreateException
    {
        firstName = aFirstName;
        middleName = aMiddleName;
        lastName = aLastName;

        if ((firstName == null) && (lastName == null))
        {
            throw new CreateException(
                "You must supply at least a first or last name");
        }

        PreparedStatement insertStmt = null;

        try
        {
            insertStmt = conn.prepareStatement(
                "insert into address (firstName, middleName, lastName) "+
                "values (?,?,?)");

            insertStmt.setString(1, firstName);
            insertStmt.setString(2, middleName);
            insertStmt.setString(3, lastName);

            if (insertStmt.executeUpdate() == 1)
            {
                return new AddressKey(firstName, middleName, lastName);
            }
            else
            {
                throw new CreateException(
                    "Address:firstName="+firstName+",middleName="+
                    middleName+",lastName="+lastName);
            }
        }
        catch (SQLException sqlExc)
        {
            throw new EJBException(sqlExc.toString());
        }
        finally
        {
            try
            {
                insertStmt.close();
            }
            catch (SQLException ignore)
            {
            }
        }
    }

    public void ejbPostCreate(String aFirstName, String aMiddleName,
        String aLastName)
    {
    }

    public String getFirstName() { return firstName; }
    public void setFirstName(String theFirstName)    {
        firstName = theFirstName;
    }

    public String getMiddleName() { return middleName; }
    public void setMiddleName(String theMiddleName)    {
        middleName = theMiddleName;
    }

    public String getLastName() { return lastName; }
    public void setLastName(String theLastName)    {
        lastName = theLastName;
    }

    public String getHomePhoneNumber() { return homePhoneNumber; }
    public void setHomePhoneNumber(String theHomePhoneNumber)    {
        homePhoneNumber = theHomePhoneNumber;
    }

    public String getWorkPhoneNumber() { return workPhoneNumber; }
    public void setWorkPhoneNumber(String theWorkPhoneNumber)    {
        workPhoneNumber = theWorkPhoneNumber;
    }

    public String getMobilePhoneNumber() { return mobilePhoneNumber; }
    public void setMobilePhoneNumber(String theMobilePhoneNumber)    {
        mobilePhoneNumber = theMobilePhoneNumber;
    }

    public String getAddress1() { return address1; }
    public void setAddress1(String theAddress1)    {
        address1 = theAddress1;
    }

    public String getAddress2() { return address2; }
    public void setAddress2(String theAddress2)    {
        address2 = theAddress2;
    }

    public String getCity() { return city; }
    public void setCity(String theCity)    {
        city = theCity;
    }

    public String getState() { return state; }
    public void setState(String theState)    {
        state = theState;
    }

    public String getZip() { return zip; }
    public void setZip(String theZip)    {
        zip = theZip;
    }

    public String getEmail() { return email; }
    public void setEmail(String theEmail)    {
        email = theEmail;
    }

    public void ejbActivate()
    {
    }

    public void ejbPassivate()
    {
    }

    public void ejbLoad()
    {
        PreparedStatement loadStmt = null;

        try
        {
            loadStmt = conn.prepareStatement(
                "select homePhoneNumber, workPhoneNumber,"+
                "mobilePhoneNumber,address1,address2,city,state,zip,email"+
                " from address where firstName=? and middleName=?"+
                " and lastName=?");

            loadStmt.setString(1, firstName);
            loadStmt.setString(2, middleName);
            loadStmt.setString(3, lastName);

            ResultSet results = loadStmt.executeQuery();

            if (results.next())
            {
                homePhoneNumber = results.getString(1);
                workPhoneNumber = results.getString(2);
                mobilePhoneNumber = results.getString(3);
                address1 = results.getString(4);
                address2 = results.getString(5);
                city = results.getString(6);
                state = results.getString(7);
                zip = results.getString(8);
                email = results.getString(9);
            }
            else
            {
                throw new NoSuchEntityException(
                    "Address:firstName="+firstName+",middleName="+
                    middleName+",lastName="+lastName);
            }
        }
        catch (SQLException sqlExc)
        {
            throw new EJBException(sqlExc.toString());
        }
        finally
        {
            try
            {
                loadStmt.close();
            }
            catch (SQLException ignore)
            {
            }
        }
    }

    public void ejbStore()
    {
        PreparedStatement updateStmt = null;

        try
        {
            updateStmt = conn.prepareStatement(
                "update address set homePhoneNumber=?, workPhoneNumber=?,"+
                "mobilePhoneNumber=?,address1=?,address2=?,city=?,"+
                "state=?,zip=?,email=? where firstName=? and "+
                "middleName=? and lastName=?");

            updateStmt.setString(1, homePhoneNumber);
            updateStmt.setString(2, workPhoneNumber);
            updateStmt.setString(3, mobilePhoneNumber);
            updateStmt.setString(4, address1);
            updateStmt.setString(5, address2);
            updateStmt.setString(6, city);
            updateStmt.setString(7, state);
            updateStmt.setString(8, zip);
            updateStmt.setString(9, email);
            updateStmt.setString(10, firstName);
            updateStmt.setString(11, middleName);
            updateStmt.setString(12, lastName);

            if (updateStmt.executeUpdate() == 0)
            {
                throw new EJBException(
                    "Unable to store "+
                    "Address:firstName="+firstName+",middleName="+
                    middleName+",lastName="+lastName);
            }
        }
        catch (SQLException sqlExc)
        {
            throw new EJBException(sqlExc.toString());
        }
        finally
        {
            try
            {
                updateStmt.close();
            }
            catch (SQLException ignore)
            {
            }
        }
    }

    public void ejbRemove()
    {
        PreparedStatement deleteStmt = null;

        try
        {
            deleteStmt = conn.prepareStatement(
                "delete from address where firstName=? and "+
                "middleName=? and lastName=?");

            deleteStmt.setString(1, firstName);
            deleteStmt.setString(2, middleName);
            deleteStmt.setString(3, lastName);

            if (deleteStmt.executeUpdate() == 0)
            {
                throw new EJBException(
                    "Unable to delete "+
                    "Address:firstName="+firstName+",middleName="+
                    middleName+",lastName="+lastName);
            }
        }
        catch (SQLException sqlExc)
        {
            throw new EJBException(sqlExc.toString());
        }
        finally
        {
            try
            {
                deleteStmt.close();
            }
            catch (SQLException ignore)
            {
            }
        }
    }

    public void setEntityContext(EntityContext aContext)
    {
        context = aContext;
        try
        {
            InitialContext iContext = new InitialContext();
            DataSource dataSource = (DataSource) iContext.lookup(dbName);

            conn = dataSource.getConnection();
        }
        catch (Exception exc)
        {
            throw new EJBException(exc.toString());
        }
    }

    public void unsetEntityContext()
    {
        context = null;
    }

    public AddressKey ejbFindByPrimaryKey(AddressKey key)
        throws FinderException
    {
        PreparedStatement findStmt = null;

        try
        {
            findStmt = conn.prepareStatement(
                "select firstName, lastName, middleName "+
                "from address where firstName=? and "+
                "middleName=? and lastName=?");

            findStmt.setString(1, key.firstName);
            findStmt.setString(2, key.middleName);
            findStmt.setString(3, key.lastName);

            ResultSet results = findStmt.executeQuery();

            if (results.next())
            {
                return key;
            }
            else
            {
                throw new ObjectNotFoundException(
                    "Unable to locate "+
                    "Address:firstName="+firstName+",middleName="+
                    middleName+",lastName="+lastName);
            }
        }
        catch (SQLException sqlExc)
        {
            throw new EJBException(sqlExc.toString());
        }
        finally
        {
            try
            {
                findStmt.close();
            }
            catch (SQLException ignore)
            {
            }
        }
    }

    public Collection ejbFindByLastName(String lastName)
    {
        return find("lastName = ?", lastName);
    }

    public Collection ejbFindByEmail(String email)
    {
        return find("email = ?", email);
    }

    public Collection ejbFindByHomePhoneNumber(String homePhone)
    {
        return find("homePhoneNumber = ?", homePhone);
    }

    public Collection ejbFindByWorkPhoneNumber(String workPhone)

    {
        return find("workPhoneNumber = ?", workPhone);
    }

    public Collection ejbFindByMobilePhoneNumber(String mobilePhone)
    {
        return find("mobilePhoneNumber = ?", mobilePhone);
    }

    public Collection find(String whereClause, String parameter)
    {
        PreparedStatement findStmt = null;

        try
        {
            findStmt = conn.prepareStatement(
                "select firstName, lastName, middleName "+
                "from address where "+whereClause);

            findStmt.setString(1, parameter);

            ResultSet results = findStmt.executeQuery();

            ArrayList retval = new ArrayList();

            while (results.next())
            {
                String firstName = results.getString(1);
                String middleName = results.getString(2);
                String lastName = results.getString(3);

                AddressKey key = new AddressKey(firstName,
                    middleName, lastName);

                retval.add(key);
            }

            return retval;
        }
        catch (SQLException sqlExc)
        {
            throw new EJBException(sqlExc.toString());
        }
        finally
        {
            try
            {
                findStmt.close();
            }
            catch (SQLException ignore)
            {
            }
        }
    }

}

