package usingjsp.xml;

import java.io.*;

import javax.servlet.*;
import javax.servlet.http.*;

import javax.xml.parsers.*;
import org.xml.sax.*;

public class SaxParseServlet extends HttpServlet
{
    public void doPost(HttpServletRequest request,
        HttpServletResponse response)
        throws ServletException, IOException
    {
        try
        {
// Create a parser factory
            SAXParserFactory factory = SAXParserFactory.newInstance();

// Ask the parser factory to create a new parser
            SAXParser parser = factory.newSAXParser();

// This servlet just sends a plain text response
            response.setContentType("text/plain");

// Create an input source around the request reader, ask the parser
// to parse the input source and invoke methods in the XMLHandler class
// when it finds XML elements
            parser.parse(new InputSource(request.getReader()),
                new XMLHandler(request, response));
        }
        catch (ParserConfigurationException exc)
        {
            throw new ServletException(exc.toString());
        }
        catch (SAXException exc)
        {
            throw new ServletException(exc.toString());
        }
    }

    class XMLHandler extends HandlerBase
    {
        protected HttpServletRequest request;
        protected HttpServletResponse response;

        protected boolean handlingFirstName;
        protected boolean handlingLastName;
        protected boolean inName;

        protected String firstName;
        protected String lastName;

        public XMLHandler(HttpServletRequest aRequest,
            HttpServletResponse aResponse)
        {
            request = aRequest;
            response = aResponse;

            inName = false;
            handlingFirstName = false;
            handlingLastName = false;
        }

        public void startElement(String name, AttributeList attributes)
        {
// Look for a <name> element
            if (name.equals("name"))
            {
                inName = true;
                firstName = null;
                lastName = null;
            }
// If inside a <name> element, look for <first>
            else if (name.equals("first"))
            {
                if (!inName) return;

                handlingFirstName = true;
            }
// If inside a <name> element, look for <last>
            else if (name.equals("last"))
            {
                if (!inName) return;

                handlingLastName = true;
            }
        }

        public void characters(char[] chars, int start, int length)
        {
// If these characters are occurring inside a <first> element, save them
            if (handlingFirstName)
            {
                firstName = new String(chars, start, length);
            }
// If these characters are occurring inside a <last> element, save them
            else if (handlingLastName)
            {
                lastName = new String(chars, start, length);
            }
            else
            {
                return;
            }
        }

        public void endElement(String name)
            throws SAXException
        {
            if (name.equals("name"))
            {
// After the end of the name element, if there's a first and a last name,
// print them separated by a space
                if ((firstName != null) && (lastName != null))
                {
                    try
                    {
                        PrintWriter out = response.getWriter();

                        out.println(firstName+" "+lastName);
                    }
                    catch (IOException ioExc)
                    {
                        throw new SAXException(ioExc.toString());
                    }
                }
                inName = false;
            }
            else if (name.equals("first"))
            {
                if (!inName) return;
                handlingFirstName = false;
            }
            else if (name.equals("last"))
            {
                if (!inName) return;
                handlingLastName = false;
            }
        }
    }
}
