package usingjsp;

import java.awt.*;
import java.awt.image.*;
import java.awt.geom.*;
import java.io.*;
import com.sun.image.codec.jpeg.*;
import javax.servlet.*;
import javax.servlet.http.*;

public class ImageCaptionServlet extends HttpServlet implements ImageObserver
{
    public void doGet(HttpServletRequest request,
        HttpServletResponse response)
        throws IOException
    {
// Make sure the browser calls this servlet every time
        response.setHeader("Cache-Control", "no-cache");
        response.setHeader("Pragma", "no-cache");
        response.setHeader("Expires", "0");

        HttpSession session = request.getSession();

// Get the in-memory image
        BufferedImage buffImage =
            (BufferedImage) session.getAttribute("image");
        
// If there's no image, create a blank one
        if (buffImage == null)
        {
            buffImage = new BufferedImage(100, 100,
                BufferedImage.TYPE_INT_RGB);
        }

// Create a new image to hold the original image plus the caption
        BufferedImage outputImage =
            new BufferedImage(buffImage.getWidth(),
                buffImage.getHeight(), BufferedImage.TYPE_INT_RGB);

// Get a graphics context for drawing to the new image
        Graphics2D g = (Graphics2D) outputImage.getGraphics();

// Copy the old image onto the new one
        g.drawImage(buffImage, 0, 0, this);

// Get the captioning parameters
        String caption = request.getParameter("caption");
        if (caption == null) caption = "<<caption>>";

        String location = request.getParameter("location");
        if (location == null) location = "bottom";

        String fontStr = request.getParameter("font");
        if (fontStr == null) fontStr = "times";

        int style = Font.PLAIN;
        String styleStr = request.getParameter("style");
        if (styleStr.equals("italic")) style = Font.ITALIC;
        if (styleStr.equals("bold")) style = Font.BOLD;

        int size = 8;
        String sizeStr = request.getParameter("size");

        if (sizeStr != null)
        {
            try
            {
                size = Integer.parseInt(sizeStr);
            }
            catch (Exception ignore) {}
        }

        int color = 0xffffff; 
        String colorStr = request.getParameter("color");
        if (colorStr != null)
        {
            try
            {
                color = Integer.parseInt(colorStr);
            }
            catch (Exception ignore) {}
        }

        Color fontColor = new Color(color);
        Font font = new Font(fontStr, style, size);

// See how big the caption will be on the image
        Rectangle2D bounds = font.getStringBounds(
            caption, g.getFontRenderContext());

// The X value is computed to make the text appear centered
        int x = (int) ((outputImage.getWidth() - bounds.getWidth()) / 2);

// Put the text at the top by default
        int y = (int) (bounds.getHeight());

// .. but allow the user to put it at the bottom
        if (location.equals("bottom"))
        {
            y = outputImage.getHeight()-1;
        }

        g.setColor(fontColor);
        g.setFont(font);

// Draw the caption
        g.drawString(caption, x, y);

        response.setContentType("image/jpeg");

// Create an encoder to convert the image into JPEG format, using
// the servlet's output stream as the stream for writing the image
        JPEGImageEncoder encoder = JPEGCodec.createJPEGEncoder(
            response.getOutputStream());

// Convert the image to JPeg
        encoder.encode(outputImage);

    }
    public boolean imageUpdate(Image img, int infoFlags, int x, int y,
        int width, int height)
    {
        return false;
    }
}


